//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
// --------------------------------------------------------------
//      GEANT 4 -
//
//      For information related to this code contact:
//
// --------------------------------------------------------------
// Comments
//
// --------------------------------------------------------------

// G4 includes
#include "G4RunManager.hh"
#include "G4UImanager.hh"
#include "G4UIterminal.hh"
#include "G4UItcsh.hh"

#ifdef G4VIS_USE
#include "G4VisExecutive.hh"
#endif

#ifdef G4UI_USE
#include "G4UIExecutive.hh"
#endif

// application includes
#include "ARedSphereConstruction.hh"
#include "ABlueCubeConstruction.hh"

#include "AGeantinoGun.hh"
#include "AGammaGun.hh"
#include "AProtonGun.hh"

#include "AGeantinoPhysicsList.hh"
#include "AnElectroMagneticPhysicsList.hh"
#include "AnHadronicPhysicsList.hh"

// The User's main program to control / run simulations
int main(int argc, char** argv)
{
  // Construct the default run manager which is necessary for G4 kernel to control everything
  G4RunManager *theRunManager = new G4RunManager();
  theRunManager->SetVerboseLevel(1);
	
  // Then add mandatory initialization G4 classes provided by the USER
  // detector construction
  // physics  list
  // initialisation of the generator
    
  
  ARedSphereConstruction* sphereConstruction = new ARedSphereConstruction();
  ABlueCubeConstruction* cubeConstruction    = new ABlueCubeConstruction();
  G4RunManager::GetRunManager()->SetUserInitialization( sphereConstruction );


  AGeantinoPhysicsList* geantinoPhysicsList = new AGeantinoPhysicsList();
  AnElectroMagneticPhysicsList* electromagneticPhysicsList = new AnElectroMagneticPhysicsList();
  AnHadronicPhysicsList* hadronicPhysicsList = new AnHadronicPhysicsList();
  G4RunManager::GetRunManager()->SetUserInitialization( hadronicPhysicsList );


  AGeantinoGun* geantinoGun = new AGeantinoGun();
  AGammaGun* gammaGun = new AGammaGun();
  AProtonGun* protonGun = new AProtonGun();
 
  G4RunManager::GetRunManager()->SetUserAction( protonGun );
    
    
  // in case something is wrong
  if ( G4RunManager::GetRunManager()->GetUserPhysicsList() == 0x0 ) {
    G4cerr << G4endl << " ***** ERROR ***** The PHYSICS LIST is not set ***** ERROR ***** " << G4endl;
    exit (-1);
  }
  if ( G4RunManager::GetRunManager()->GetUserDetectorConstruction() == 0x0 ) {
    G4cerr << G4endl << " ***** ERROR ***** The DETECTOR is not built ***** ERROR ***** " << G4endl;
    exit (-1);
  }
  if ( G4RunManager::GetRunManager()->GetUserPrimaryGeneratorAction() == 0x0 ) {
    G4cerr << G4endl << " ***** ERROR ***** The Primary generator is not defined ***** ERROR ***** " << G4endl;
    exit (-1);
  }
    
  // Initialize G4 kernel
  theRunManager->Initialize();

  // Get the pointer to the User Interface manager
  G4UImanager * UImanager = G4UImanager::GetUIpointer();  

  // And the Visualization manager
  G4VisManager* visManager = new G4VisExecutive();
  //
  if ( visManager ) {
    visManager->SetVerboseLevel(G4VisManager::quiet);
    visManager->Initialize();
  }
    
  G4UIsession *session = 0x0;
#ifdef G4UI_USE
      G4UIExecutive * ui = new G4UIExecutive(argc,argv);
#ifdef G4VIS_USE
      UImanager->ApplyCommand("/control/execute vis.mac");     
#endif
      ui->SessionStart();
      delete ui;
#endif    
  // job termination
  delete session;
    
  if ( visManager ) delete visManager;
  delete theRunManager;
	
  return 0; 
}






