//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
// $Id: ABlueCubeConstruction.hh,v 1.8 2006/06/29 17:47:30 gunter Exp $
// GEANT4 tag $Name: geant4-08-02 $
//
#ifndef ABlueCubeConstruction_h
#define ABlueCubeConstruction_h 1

#include "G4VUserDetectorConstruction.hh"

class G4Box;
class G4LogicalVolume;
class G4VPhysicalVolume;
class G4Material;

//! The detector is a blue cube which position, side and material can be modified
/*!
 */
class ABlueCubeConstruction : public G4VUserDetectorConstruction
{
private:
  G4double X_Center;
  G4double Y_Center;
  G4double Z_Center;
    
  G4double Side;
  G4String MatName;
    
public:
  ABlueCubeConstruction(G4double xc = 0.0, G4double yc = 0.0, G4double zc = 0.0, G4double s = 25.*CLHEP::cm, G4String mat = "G4_WATER");
  virtual ~ABlueCubeConstruction();
    
  //! One of the mandatory class to be implemented in order to have G4 working properly
  G4VPhysicalVolume* Construct();

  G4VPhysicalVolume* GetPhysicalWorld() {return physiWorld;}
    
private:
  G4Box*             solidWorld;    // pointer to the solid envelope
  G4LogicalVolume*   logicWorld;    // pointer to the logical envelope
  G4VPhysicalVolume* physiWorld;    // pointer to the physical envelope

  G4Material*        WorldMaterial; // pointer to the world material  
  G4Material*        CubeMaterial;  // pointer to the cube material  
};
#endif

