//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
#ifndef ARedSphereConstruction_h
#define ARedSphereConstruction_h 1

#include "G4VUserDetectorConstruction.hh"
#include "G4VPhysicalVolume.hh"
#include "G4LogicalVolume.hh"
#include "G4Box.hh"
#include "G4Sphere.hh"
#include "G4Material.hh"
#include "G4Tubs.hh"
#include <G4Torus.hh>
#include <G4Orb.hh>

#include "G4PVPlacement.hh"
#include "G4UserLimits.hh"
#include "G4VisAttributes.hh"

//class G4Box;
//class G4LogicalVolume;
//class G4VPhysicalVolume;
//class G4Material;

//! The detector is a red sphere which position, radius and material can be modified
/*!
 */
class ARedSphereConstruction : public G4VUserDetectorConstruction
{
private:
  G4double X_Center;
  G4double Y_Center;
  G4double Z_Center;
    
  G4double Radius;
  G4String MatName;
  
public:
  ARedSphereConstruction(G4double xc = 0.0, G4double yc = 0.0, G4double zc = 0.0, G4double r = 25.*CLHEP::cm, G4String mat = "G4_WATER");
  virtual ~ARedSphereConstruction();

  //! One of the mandatory class to be implemented in order to have G4 working properly
  G4VPhysicalVolume* Construct();

  G4VPhysicalVolume* GetPhysicalWorld() {return physiWorld;}
  
private:

 G4double           WorldSizeX;
  G4double           WorldSizeY;
  G4double           WorldSizeZ;

  G4VPhysicalVolume* physiWorld;
  G4LogicalVolume*   logicWorld;  
  G4Box*             solidWorld;
  
  G4double           World1SizeX;
  G4double           World1SizeY;
  G4double           World1SizeZ;

  G4VPhysicalVolume* physiWorld1;
  G4LogicalVolume*   logicWorld1;  
  G4Box*             solidWorld1;

  G4VPhysicalVolume* physiTarget;
  G4LogicalVolume*   logicTarget;  
  G4Box*             solidTarget;
  
  G4VPhysicalVolume* physiTarget_m;
  G4LogicalVolume*   logicTarget_m;  
  G4Box*             solidTarget_m;
  
  G4VPhysicalVolume* physiSc;
  G4LogicalVolume*   logicSc;  
  G4Box*             solidSc;
  
   G4VPhysicalVolume* physiColle;
  G4LogicalVolume*   logicColle;  
  G4Box*             solidColle;
  
  G4VPhysicalVolume* physiPM_ext;
  G4LogicalVolume*   logicPM_ext;  
  G4Sphere*          solidPM_ext;
  
  G4VPhysicalVolume* physiSphere_colle;
  G4LogicalVolume*   logicSphere_colle;  
  G4Sphere*          solidSphere_colle;
  
  G4VPhysicalVolume* physiVide;
  G4LogicalVolume*   logicVide;  
  G4Box*          solidVide;
  
  G4VPhysicalVolume* physiPM_exterieur;
  G4LogicalVolume*   logicPM_exterieur;  
  G4Sphere*          solidPM_exterieur;
  
  G4VPhysicalVolume* physiPM_interieur;
  G4LogicalVolume*   logicPM_interieur;  
  G4Sphere*          solidPM_interieur;
  
  G4VPhysicalVolume* physiVerre_PM;
  G4LogicalVolume*   logicVerre_PM;  
  G4Sphere*          solidVerre_PM;
  
  G4VPhysicalVolume* physiPM_int;
  G4LogicalVolume*   logicPM_int;  
  G4Sphere*          solidPM_int;
  
  G4VPhysicalVolume* physiSphere_sc;
  G4LogicalVolume*   logicSphere_sc;  
  G4Sphere*          solidSphere_sc;
  
  G4VPhysicalVolume* physiTore1;
  G4LogicalVolume*   logicTore1;  
  G4Sphere*          solidTore1;

  G4VPhysicalVolume* physiTargetMylar;
  G4LogicalVolume*   logicTargetMylar;  
  G4Box*             solidTargetMylar;

  G4VPhysicalVolume* physiTargetAlu_int;
  G4LogicalVolume*   logicTargetAlu_int;  
  G4Box*             solidTargetAlu_int;
   
  G4VPhysicalVolume* physiTargetAlu_ext;
  G4LogicalVolume*   logicTargetAlu_ext;  
  G4Box*             solidTargetAlu_ext;  
  
  G4Material*        defaultMaterial;
  G4Material*        waterMaterial;
  G4Material*        AluMaterial;
  G4Material*	     BC404Material;
  G4Material*        MylarMaterial;
  G4Material*        VacuumMaterial;
  G4Material*        RTV615Material;
  G4Material*        VerreMaterial;

 void DefineMaterials();

  G4VPhysicalVolume* ConstructDetector();   
 
  /*G4Box*             solidWorld;  // pointer to the solid envelope 
  G4LogicalVolume*   logicWorld;  // pointer to the logical envelope
  G4VPhysicalVolume* physiWorld;  // pointer to the physical envelope

  G4Material* WorldMaterial;      // pointer to the world material
  G4Material* SphereMaterial;     // pointer to the sphere material*/
};
#endif

