//
// ********************************************************************
// * License and Disclaimer                                           *
// *                                                                  *
// * The  Geant4 software  is  copyright of the Copyright Holders  of *
// * the Geant4 Collaboration.  It is provided  under  the terms  and *
// * conditions of the Geant4 Software License,  included in the file *
// * LICENSE and available at  http://cern.ch/geant4/license .  These *
// * include a list of copyright holders.                             *
// *                                                                  *
// * Neither the authors of this software system, nor their employing *
// * institutes,nor the agencies providing financial support for this *
// * work  make  any representation or  warranty, express or implied, *
// * regarding  this  software system or assume any liability for its *
// * use.  Please see the license in the file  LICENSE  and URL above *
// * for the full disclaimer and the limitation of liability.         *
// *                                                                  *
// * This  code  implementation is the result of  the  scientific and *
// * technical work of the GEANT4 collaboration.                      *
// * By using,  copying,  modifying or  distributing the software (or *
// * any work based  on the software)  you  agree  to acknowledge its *
// * use  in  resulting  scientific  publications,  and indicate your *
// * acceptance of all terms of the Geant4 Software license.          *
// ********************************************************************
//
//
 
// G4 includes
#include "G4Material.hh"
#include "G4Box.hh"
#include "G4Sphere.hh"
#include "G4LogicalVolume.hh"
#include "G4PVPlacement.hh"
#include "G4VisAttributes.hh"
#include "G4Colour.hh"
#include "G4ios.hh"
#include "G4NistManager.hh"
#include <G4SubtractionSolid.hh>
#include <G4UnionSolid.hh>

#include "ARedSphereConstruction.hh"
	
/*ARedSphereConstruction::ARedSphereConstruction(G4double xc, G4double yc, G4double zc, G4double r, G4String mat):
  X_Center(xc),
  Y_Center(yc),
  Z_Center(zc),
  Radius(r),
  MatName(mat),
  solidWorld(0),
  logicWorld(0),
  physiWorld(0),
  WorldMaterial(0),
  SphereMaterial(0)
{

  G4NistManager* man = G4NistManager::Instance();
  WorldMaterial = man->FindOrBuildMaterial("G4_AIR");
  SphereMaterial = man->FindOrBuildMaterial(MatName);

  // to check if the material with the name "MatName" exists in the G4 material database
  if(!SphereMaterial){ 
    const G4String errorMessage("the material of the Red Sphere is undefined -> you asked for the material " + 
				MatName + " but such material does not exist in the GEANT4 database!");

    G4Exception("ARedSphereConstruction::ARedSphereConstruction()", 
		"SphereMaterial = man->FindOrBuildMaterial(MatName)", 
		FatalErrorInArgument, 
		errorMessage);  
  }


  // To print some info
  G4cout << G4endl << " ------ INFO ------ Your detector is composed of a Red Sphere of "
	 << MatName << " centered at " << X_Center << " " << Y_Center << " " << Z_Center << " and with radius " << Radius << G4endl;
  
}

ARedSphereConstruction::~ARedSphereConstruction()
{
  ; // nothing to be deleted
}


G4VPhysicalVolume* ARedSphereConstruction::Construct()
{
  // this is the shape of the world. Make sure it is large enough to contain everything
  const G4double HalfWorldLength = sqrt( X_Center*X_Center + Y_Center*Y_Center + Z_Center*Z_Center) + 2*Radius;
    
  solidWorld = new G4Box("TheWorld",HalfWorldLength,HalfWorldLength,HalfWorldLength);
  logicWorld = new G4LogicalVolume(solidWorld, WorldMaterial, "TheWorld", 0, 0, 0);
	
  logicWorld->SetVisAttributes(G4VisAttributes::Invisible); // hide the world
	
  //  Must place the World Physical volume unrotated at (0,0,0).
  physiWorld = new G4PVPlacement(0,         // no rotation
				 G4ThreeVector(), // at (0,0,0)
				 logicWorld,      // its logical volume
				 "TheWorld",      // its name
				 0,               // its mother  volume
				 false,           // no boolean operations
				 -1);              // copy number
	
  // Now add a red sphere to the world
  G4Sphere *asolidShell; 
  G4LogicalVolume *alogicShell; 
  G4VPhysicalVolume *aphysiShell; 
  G4VisAttributes *visatt;
	
  asolidShell = new G4Sphere(MatName, 0, Radius, 0.0, 360.0*CLHEP::deg, 0.0, 180.0*CLHEP::deg);
  alogicShell = new G4LogicalVolume(asolidShell, SphereMaterial, "RedSphere", 0, 0, 0);

  // the sphere is red
  visatt = new G4VisAttributes( G4Colour(0.0, 0.0, 1.0) );
  visatt->SetVisibility(true);
  alogicShell->SetVisAttributes( visatt );
    
  aphysiShell = new G4PVPlacement(0,        // no rotation
				  G4ThreeVector(X_Center, Y_Center, Z_Center), // at (X_Center,Y_Center,Z_Center)
				  alogicShell,     // its logical volume
				  "RedSphere",     // its name
				  logicWorld,      // its mother  volume
				  false,           // no boolean operations
				  0);              // copy number

    
  // The Physical World is returned there ... this is what G4 Kernel needs to works with your simulations
  return physiWorld;
}
*/

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

DetectorConstruction::DetectorConstruction()
:physiWorld(NULL), logicWorld(NULL), solidWorld(NULL)
{}  

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

DetectorConstruction::~DetectorConstruction()
{}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

G4VPhysicalVolume* DetectorConstruction::Construct()

{
  DefineMaterials();
  return ConstructDetector();
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

void DetectorConstruction::DefineMaterials()
{ 
  G4String name, symbol;             
  G4double density;            
  
  G4int ncomponents, natoms;
  G4double z, a;
  G4double fractionmass;
  
  // Define Elements  
  // Example: G4Element* Notation  = new G4Element ("Element", "Notation", z, a);
  G4Element*   H  = new G4Element ("Hydrogen", "H", 1. ,  1.01*g/mole);
  G4Element*   N  = new G4Element ("Nitrogen", "N", 7., 14.01*g/mole);
  G4Element*   O  = new G4Element ("Oxygen"  , "O", 8. , 16.00*g/mole);
  G4Element*  Al = new G4Element ("Aluminium", "Al", 13., 26.98154*g/mole);
  G4Element*  C = new G4Element ("Carbon", "C", 6., 12*g/mole); 
  G4Element*  Si = new G4Element ("Silicium", "Si", 14., 28.0855*g/mole); 
  G4Element*  B = new G4Element ("Bore", "B", 5., 10.811*g/mole);
  G4Element*   Na  = new G4Element ("Sodium", "Na",11,22.989770*g/mole);
  //G4Element*   Ti = new G4Element( "Titanium","Ti", 22, 47.88*g/mole);
 
  // Define Material
  
  // Case 1: chemical molecule  
  // Water 
  density = 1.000*g/cm3;
  G4Material* H2O = new G4Material(name="H2O"  , density, ncomponents=2);
  H2O->AddElement(H, natoms=2);
  H2O->AddElement(O, natoms=1);
  
  // Mylar 
  density= 1.40*g/cm3;
  G4Material* Mylar = new G4Material(name="Mylar", density, ncomponents=3);
  Mylar->AddElement(H, natoms=4);
  Mylar->AddElement(C, natoms=5);
  Mylar->AddElement(O, natoms=2);
  
  //Colle RTV 615
  density= 0.99*g/cm3;
  G4Material* RTV615 = new G4Material(name="RTV615",density, ncomponents=4);
  RTV615->AddElement(H, natoms=6);
  RTV615->AddElement(C, natoms=2);
  RTV615->AddElement(O, natoms=1);
  RTV615->AddElement(Si, natoms=1);
  

  // Aluminium
  density = 2.6989*g/cm3;
  G4Material* Alu = new G4Material(name="Alu" , density, ncomponents=1);
  Alu->AddElement(Al, natoms=1);
  
  // Case 2: mixture by fractional mass.
  // Air
  density = 1.290*mg/cm3;
  G4Material* Air = new G4Material(name="Air"  , density, ncomponents=2);
  Air->AddElement(N, fractionmass=0.7);
  Air->AddElement(O, fractionmass=0.3);

  // Scintillateur Plastique BC404
  density = 1.032*g/cm3;
  G4Material* BC404 = new G4Material(name="BC404", density, ncomponents=2);
  BC404->AddElement(C, fractionmass=0.474);
  BC404->AddElement(H, fractionmass=0.526);
  
   // Silicon Dioxide
  G4Material* SiO2 = new G4Material("SiO2",2.6*g/cm3,2,kStateSolid);
  SiO2->AddElement(O,natoms=2);
  SiO2->AddElement(Si,natoms=1);

  // DiBoron TriOxide
  G4Material* B2O3 = new G4Material("B2O3",2.46*g/cm3,2,kStateSolid);
  B2O3->AddElement(B,natoms=2);
  B2O3->AddElement(O,natoms=3);

  // DiSodium Monoxide
  G4Material* Na2O = new G4Material("Na2O",2.27*g/cm3,2,kStateSolid);
  Na2O->AddElement(Na,natoms=2);
  Na2O->AddElement(O,natoms=1);

  // Aluminum Peroxide
  G4Material* Al2O3 = new G4Material("Al2O3",3.97*g/cm3,2,kStateSolid);
  Al2O3->AddElement(Al,natoms=2);
  Al2O3->AddElement(O,natoms=3);
  
    //Verre PM
  G4Material* Verre_pm = new G4Material("Verre_pm",
                      2.23*g/cm3,
                      4,
                      kStateSolid,
                      273.15*kelvin,
                      1.0*atmosphere );


  Verre_pm->AddMaterial(SiO2, 0.81);
  Verre_pm->AddMaterial(B2O3, 0.13);
  Verre_pm->AddMaterial(Na2O, 0.04);
  Verre_pm->AddMaterial(Al2O3, 0.02);

  // Vaccum                                      standard definition...
  density = universe_mean_density;
  G4Material* vacuum = new G4Material(name="Vacuum", z=1., a=1.01*g/mole,
	density);

  G4cout << G4endl << *(G4Material::GetMaterialTable()) << G4endl;

  // Default materials in setup.
  defaultMaterial = vacuum; //Air
  waterMaterial = H2O;
  AluMaterial = vacuum; //Alu
  BC404Material = BC404;
  MylarMaterial = vacuum;  //Mylar
  VacuumMaterial = vacuum;
  RTV615Material = RTV615;
  VerreMaterial = Verre_pm;
}

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....
G4VPhysicalVolume* DetectorConstruction::ConstructDetector()
{

//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

  // WORLD VOLUME
  
  WorldSizeX  = 50.*cm;  
  WorldSizeY  = 50.*cm;    //11*cm
  WorldSizeZ  = 50.*cm; 

  solidWorld = new G4Box("World",				     //its name
			   WorldSizeX/2,WorldSizeY/2,WorldSizeZ/2);  //its size
  

  logicWorld = new G4LogicalVolume(solidWorld,	        //its solid
				   defaultMaterial,	//its material
				   "World");		//its name
  
  physiWorld = new G4PVPlacement(0,			//no rotation
  				 G4ThreeVector(),	//at (0,0,0)
                                 "World",		//its name
                                 logicWorld,		//its logical volume
                                 NULL,			//its mother  volume
                                 false,			//no boolean operation
                                 0);			//copy number
				 
				 
 // CREATION D UN SECOND WORLD POUR COMPTAGE PHOTONS
 
 World1SizeX  = 49.999*cm;  
  World1SizeY  = 49.999*cm;    //11*cm
  World1SizeZ  = 49.999*cm; 

  solidWorld1 = new G4Box("World1",				     //its name
			   World1SizeX/2,World1SizeY/2,World1SizeZ/2);  //its size
  

  logicWorld1 = new G4LogicalVolume(solidWorld1,	        //its solid
				   defaultMaterial,	//its material
				   "World1");		//its name
  
  physiWorld1 = new G4PVPlacement(0,			//no rotation
  				 G4ThreeVector(),	//at (0,0,0)
                                 "World1",		//its name
                                 logicWorld1,		//its logical volume
                                 physiWorld,			//its mother  volume
                                 false,			//no boolean operation
                                 0);				 


  // TARGET VOLUMES 

 
// Définition de la marche du scintillateur en BC404

 /* solidTarget_m = new G4Box("Target_m",			
			      12.8*cm, 12.8*cm,	     //12.8*cm   
			       15.5*mm);  //0.150000*mm  ->valeur à moi 15.5mm              
  

  logicTarget_m = new G4LogicalVolume(solidTarget_m,	//its solid
				   BC404Material,  	//its material
				   "Target_m");		//its name
  physiTarget_m = new G4PVPlacement(
   				 0,			//rotation
  				 G4ThreeVector(0,0,0),// transl
				 "Target_m",		//its name
                                 logicTarget_m,		//its logical volume
                                 physiWorld,		//its mother  volume
                                 false,			//no boolean operation
                                 0);			//copy number
				 
				 
// Définition du scintillateur en BC404

  solidTarget = new G4Box("Target",			
			      11.8*cm, 11.8*cm,	     //5.*cm   
			       81.5*mm);  //0.150000*mm  ->valeur à moi 10mm              
  

  logicTarget = new G4LogicalVolume(solidTarget,	//its solid
				   BC404Material,  	//its material
				   "Target");		//its name
  physiTarget = new G4PVPlacement(
   				 0,			//rotation
  				 G4ThreeVector(0,0,-9.7*cm),// transl
				 "Target",		//its name
                                 logicTarget,		//its logical volume
                                 physiWorld,		//its mother  volume
                                 false,			//no boolean operation
                                 0);			//copy number

 
 */
 
 //Marche du scintillateur
   solidTarget_m = new G4Box("Target_m",			
			      12.8*cm, 12.8*cm,	     //12.8*cm   
			       15.5*mm);  //0.150000*mm  ->valeur à moi 15.5mm  
			   

//Corps du scintillateur
  solidTarget = new G4Box("Target",			
			      11.8*cm, 11.8*cm,	     //5.*cm   
			       81.5*mm);  //0.150000*mm  ->valeur à moi 10mm 
			       
			       
//ADDITION DES DEUX VOLUMES

 G4RotationMatrix* noRot = new G4RotationMatrix(0,0,0);
     G4ThreeVector zTrans(0, 0, -97.*mm);//-97
     G4UnionSolid* solidSc = new G4UnionSolid("Target+Target_m",solidTarget_m,solidTarget,noRot,zTrans); 
     
     
  logicSc = new G4LogicalVolume(solidSc,	//its solid
				   BC404Material,  	//its material
				   "Sc");		//its name
  physiSc = new G4PVPlacement(
   				 0,			//rotation
  				 G4ThreeVector(0,0,15*cm),// transl
				 "Sc",		//its name
                                 logicSc,		//its logical volume
                                 physiWorld1,		//its mother  volume
                                 false,			//no boolean operation
                                 0);			//copy number	
				 
				 
				 
//Creation du volume de colle

  solidSphere_colle = new G4Sphere("Sphere_colle",
               0,
               79.5*mm,
               0,
               2*3.1415927 ,
               0.,
               0.39*3.1415927) ;//0.336
	     
	     				 
  solidVide = new G4Box("Vide",			
			      11.8*cm, 11.8*cm,	       
			       39.4*mm);//39.4               
  				 	
										 
G4ThreeVector aTrans(0, 0, 0*mm);
 
 G4SubtractionSolid* solidColle = new G4SubtractionSolid("Colle", solidSphere_colle,solidVide,noRot,aTrans); 
 
 logicColle = new G4LogicalVolume(solidColle,		//its solid
				   RTV615Material,   			//its material
				   "Colle");			//its name
				   
  physiColle = new G4PVPlacement(
   				 0,					//rotation
  				 G4ThreeVector(0,0,-68*mm),	// transl 136.5 -68
				 "Colle",			//its name
                                 logicColle,			//its logical volume
                                 physiWorld1,				//its mother  volume
                                 false,					//no boolean operation
                                 0);				 
				 			   			      
		       			   						
 
 //Creation du verre de PM extérieur

  solidPM_exterieur = new G4Sphere("PM_exterieur",
               0,
               73.05*mm, //76.37
               0,
               2*3.1415927 ,
               0.,
               0.3475*3.1415927) ;//0.3385
	       
			 
			 
				 
				 
 //Creation du verre de PM intérieur

  solidPM_interieur = new G4Sphere("PM_interieur",
               0,
               71.05*mm, //74.37
               0,
               2*3.1415927 ,
               0.,
               0.6*3.1415927) ;
	      
				 
				 
				 
G4SubtractionSolid* solidVerre_PM = new G4SubtractionSolid("Verre_PM", solidPM_exterieur,solidPM_interieur,noRot,aTrans); 
 
 logicVerre_PM = new G4LogicalVolume(solidVerre_PM,		//its solid
				   VerreMaterial,   			//its material
				   "Verre_PM");			//its name
				   
  physiVerre_PM = new G4PVPlacement(
   				 0,					//rotation
  				 G4ThreeVector(0,0,-61.85*mm),	// transl -65.17
				 "Verre_PM",			//its name
                                 logicVerre_PM,			//its logical volume
                                 physiWorld1,				//its mother  volume
                                 false,					//no boolean operation
                                 0);				 
				 
				 
				 
//Creation du Tore
 /* solidTore1 = new G4Sphere("Tore1",
             0*mm,
             53.8*mm,
             0,//53.81
             2*3.1415927,
	     0,
             2*3.1415927) ;	
	   
  logicTore1 = new G4LogicalVolume(solidTore1,		//its solid
				   VacuumMaterial,   			//its material
				   "Tore");			//its name
				   
  physiTore1 = new G4PVPlacement(
   				 0,					//rotation
  				 G4ThreeVector(0*mm,14.2*mm,-196.58*mm),	// transl 136.5
				 "Tore1",			//its name
                                 logicTore1,			//its logical volume
                                 physiWorld,				//its mother  volume
                                 false,					//no boolean operation
                                 0);	*/
				 
				 
				 
		 			      			 
 
 
 //Définition de la premiere couche d'aluminium
 
 // solidTargetAlu_int = new G4Box("TargetAlu_int",			
			    //  5.*cm, 5.*cm,	        
			     //  0.000250*mm);                  
  

 // logicTargetAlu_int = new G4LogicalVolume(solidTargetAlu_int,		//its solid
				  // VacuumMaterial,   			//its material
				  // "TargetAlu_int");			//its name
  //physiTargetAlu_int = new G4PVPlacement(
   				// 0,					//rotation
  				// G4ThreeVector(0,0,0.150250*mm),	// transl
				// "TargetAlu_int",			//its name
                                // logicTargetAlu_int,			//its logical volume
                                // physiWorld,				//its mother  volume
                                // false,					//no boolean operation
                                // 0);					//copy number
 

 
 
 // Définition de la couche de mylar de 6 µm d'épaisseur
 
  //solidTargetMylar = new G4Box("TargetMylar",			
			     // 5.*cm, 5.*cm,	        
			      // 0.003000*mm);                  
  

 // logicTargetMylar = new G4LogicalVolume(solidTargetMylar, 		//its solid
				   //VacuumMaterial,  			//its material
				  // "TargetMylar");			//its name
  //physiTargetMylar = new G4PVPlacement(
   				// 0,		 			//rotation
  				// G4ThreeVector(0,0,0.153500*mm),	// transl
				// "TargetMylar",				//its name
                                // logicTargetMylar,			//its logical volume
                                // physiWorld,				//its mother  volume
                                // false,					//no boolean operation
                                // 0);					//copy number

  //Définition de la deuxième couche d'aluminium
 
  // solidTargetAlu_ext = new G4Box("TargetAlu_ext",			
			    //  5.*cm, 5.*cm,	        
			    //   0.000250*mm);                  
  

 // logicTargetAlu_ext = new G4LogicalVolume(solidTargetAlu_ext,	//its solid
				  // VacuumMaterial,   		//its material
				   //"TargetAlu_ext");		//its name
  //physiTargetAlu_ext = new G4PVPlacement(
   				// 0,				//rotation
  				// G4ThreeVector(0,0,0.156750*mm),	// transl
				// "TargetAlu_ext",		//its name
                                // logicTargetAlu_ext,		//its logical volume
                                // physiWorld,			//its mother  volume
                               //  false,				//no boolean operation
                               //  0);				//copy number
 
 

 
 
 
 
  // Visualization attributes
  G4VisAttributes* worldVisAtt= new G4VisAttributes(G4Colour(1.0,1.0,1.0)); //White
  worldVisAtt->SetVisibility(true);
  logicWorld->SetVisAttributes(worldVisAtt);
 
  //G4VisAttributes* targetVisAtt= new G4VisAttributes(G4Colour(1.0,0.0,0.0)); //Red
  //targetVisAtt->SetForceSolid(true);
  //targetVisAtt->SetVisibility(true);
  
  //G4VisAttributes* target_mVisAtt= new G4VisAttributes(G4Colour(0.0,1.0,1.0)); //Blue
  //target_mVisAtt->SetForceSolid(true);
  //target_mVisAtt->SetVisibility(true);
  
  G4VisAttributes* ScVisAtt= new G4VisAttributes(G4Colour(0.0,1.0,1.0,0.6)); //Blue
  ScVisAtt->SetForceSolid(true);
  ScVisAtt->SetVisibility(true);
  
  G4VisAttributes* ColleVisAtt= new G4VisAttributes(G4Colour(1.0,0.0,0.0,0.5)); //Red
  ColleVisAtt->SetForceSolid(true);
  ColleVisAtt->SetVisibility(true);
   
  //G4VisAttributes* Tore1VisAtt= new G4VisAttributes(G4Colour(1.0,1.0,0.)); //Blue
  //Tore1VisAtt->SetForceSolid(true);
  //Tore1VisAtt->SetVisibility(true);
  
  /*G4VisAttributes* PM_exterieurVisAtt= new G4VisAttributes(G4Colour(0.0, 1.0, 0.0,1.0)); //Gree,
  PM_exterieurVisAtt->SetForceSolid(true);
  PM_exterieurVisAtt->SetVisibility(true); 
  
  G4VisAttributes* PM_interieurVisAtt= new G4VisAttributes(G4Colour(1.0,1.0,1.0)); //White
  PM_interieurVisAtt->SetForceSolid(true);
  PM_interieurVisAtt->SetVisibility(true); */
  
  G4VisAttributes* Verre_PMVisAtt= new G4VisAttributes(G4Colour(1.0, 1.0, 0.0)); //White
  Verre_PMVisAtt->SetForceSolid(true);
  Verre_PMVisAtt->SetVisibility(true); 
  
  //G4VisAttributes* VideVisAtt= new G4VisAttributes(G4Colour(1.0, 1.0, 0.0,0.5)); //Yellow
  //VideVisAtt->SetForceSolid(true);
  //VideVisAtt->SetVisibility(true); 
  
  //G4VisAttributes* targetMylarVisAtt= new G4VisAttributes(G4Colour(1.0,0.0,0.0)); //Red
  //targetMylarVisAtt->SetForceSolid(true);
  //targetMylarVisAtt->SetVisibility(true);
  
  //G4VisAttributes* targetAlu_intVisAtt= new G4VisAttributes(G4Colour(1.0,1.0,1.0)); //White
 // targetAlu_intVisAtt->SetForceSolid(true);
  //targetAlu_intVisAtt->SetVisibility(true);
  
  //G4VisAttributes* targetAlu_extVisAtt= new G4VisAttributes(G4Colour(1.0,1.0,1.0)); //White
  //targetAlu_extVisAtt->SetForceSolid(true);
  //targetAlu_extVisAtt->SetVisibility(true);
  
  //logicTarget->SetVisAttributes(targetVisAtt);
  //logicTarget_m->SetVisAttributes(target_mVisAtt);
  //logicSphere_sc->SetVisAttributes(Sphere_scVisAtt);
   // logicPM_exterieur->SetVisAttributes(PM_exterieurVisAtt);
  //logicPM_interieur->SetVisAttributes(PM_interieurVisAtt);
  logicSc->SetVisAttributes(ScVisAtt);
  logicColle->SetVisAttributes(ColleVisAtt);
  logicVerre_PM->SetVisAttributes(Verre_PMVisAtt);
    //logicTore1->SetVisAttributes(Tore1VisAtt);
  //logicTargetMylar->SetVisAttributes(targetMylarVisAtt);
  //logicTargetAlu_int->SetVisAttributes(targetAlu_intVisAtt); 
  //logicTargetAlu_ext->SetVisAttributes(targetAlu_extVisAtt);

 
  return physiWorld;
}
//....oooOO0OOooo........oooOO0OOooo........oooOO0OOooo........oooOO0OOooo....

