#include "AnElectroMagneticPhysicsList.hh"
#include "G4Version.hh"

//*****************************************
//             for <geant4.10             *
//*****************************************

#if G4VERSION_NUMBER < 1000

#include "G4LossTableManager.hh"

#include "G4BosonConstructor.hh"
#include "G4LeptonConstructor.hh"
#include "G4MesonConstructor.hh"
#include "G4BosonConstructor.hh"
#include "G4BaryonConstructor.hh"
#include "G4IonConstructor.hh"
#include "G4ShortLivedConstructor.hh"

#include "G4ParticleDefinition.hh"
#include "G4ProcessManager.hh"
#include "G4PhysicsListHelper.hh"

#include "G4ComptonScattering.hh"
#include "G4GammaConversion.hh"
#include "G4PhotoElectricEffect.hh"
#include "G4RayleighScattering.hh"
#include "G4KleinNishinaModel.hh"

#include "G4eMultipleScattering.hh"
#include "G4UrbanMscModel96.hh"
#include "G4eIonisation.hh"
#include "G4eBremsstrahlung.hh"
#include "G4eplusAnnihilation.hh"

#include "G4MuMultipleScattering.hh"
#include "G4MuIonisation.hh"
#include "G4MuBremsstrahlung.hh"
#include "G4MuPairProduction.hh"

#include "G4hMultipleScattering.hh"
#include "G4hIonisation.hh"
#include "G4hBremsstrahlung.hh"
#include "G4hPairProduction.hh"

#include "G4ionIonisation.hh"
#include "G4IonParametrisedLossModel.hh"
#include "G4NuclearStopping.hh"
#include "G4SystemOfUnits.hh"


AnElectroMagneticPhysicsList::AnElectroMagneticPhysicsList()
{
  G4LossTableManager::Instance();
  defaultCutValue = 1.0*mm;

  G4cout << G4endl << " ------ INFO ------ You are working with an electromagnetic PhysicsList (transportation and electromagnetic processes)" << G4endl;
}


AnElectroMagneticPhysicsList::~AnElectroMagneticPhysicsList()
{}



void AnElectroMagneticPhysicsList::ConstructParticle()
{
  // define all particles
  G4cout << G4endl << " ------ INFO ------ DEFINING PARTICLES:" << G4endl;
  G4BosonConstructor  pBosonConstructor;
  pBosonConstructor.ConstructParticle();
  G4cout << "DEFINED: Bosons" << G4endl;

  G4LeptonConstructor pLeptonConstructor;
  pLeptonConstructor.ConstructParticle();
  G4cout << "DEFINED: Leptons" << G4endl;

  G4MesonConstructor pMesonConstructor;
  pMesonConstructor.ConstructParticle();
  G4cout << "DEFINED: Mesons" << G4endl;
  
  G4BaryonConstructor pBaryonConstructor;
  pBaryonConstructor.ConstructParticle();
  G4cout << "DEFINED: Baryons" << G4endl;
  
  G4IonConstructor pIonConstructor;
  pIonConstructor.ConstructParticle();
  G4cout << "DEFINED: Ions" << G4endl;

  G4ShortLivedConstructor pShortLivedConstructor;
  pShortLivedConstructor.ConstructParticle();  
  G4cout << "DEFINED: Short lived particles" << G4endl;

  G4cout << " ------ INFO ------ PARTICLES DEFINITION FINISHED" << G4endl;
}



 void AnElectroMagneticPhysicsList::ConstructProcess()
{
  /* ###############################################
     ############### TRANSPORTATION ################
     ############################################### */

  AddTransportation();


  /* ###############################################
     ########## ELECTROMAGNETIC PROCESSES ##########
     ############################################### */

  G4PhysicsListHelper* ph = G4PhysicsListHelper::GetPhysicsListHelper();

  theParticleIterator->reset();
  while( (*theParticleIterator)() ){
    G4ParticleDefinition* particle = theParticleIterator->value();
    G4String particleName = particle->GetParticleName();
     

    // define EM physics for gamma
    if (particleName == "gamma") {
      
      // activate photoelectric effect
      ph->RegisterProcess(new G4PhotoElectricEffect, particle);  
      
      // activate Compton scattering
      G4ComptonScattering* cs   = new G4ComptonScattering;
      cs->SetEmModel(new G4KleinNishinaModel());
      ph->RegisterProcess(cs, particle);

      // activate gamma conversion
      ph->RegisterProcess(new G4GammaConversion, particle);
     
    } 
    
    // define EM physics for electron
    else if (particleName == "e-") {

      // activate multiple scattering
      G4eMultipleScattering* msc = new G4eMultipleScattering();
      msc -> AddEmModel(0, new G4UrbanMscModel96());    
      ph->RegisterProcess(msc, particle);
      
      // activate ionisation             
      G4eIonisation* eIoni = new G4eIonisation();
      eIoni->SetStepFunction(0.1, 100*um);      
      ph->RegisterProcess(eIoni, particle);
      
      // activate bremsstrahlung
      ph->RegisterProcess(new G4eBremsstrahlung(), particle);      
            
    } 

    // define EM physics for positron
    else if (particleName == "e+") {
    
      // activate multiple scattering
      G4eMultipleScattering* msc = new G4eMultipleScattering();
      msc -> AddEmModel(0, new G4UrbanMscModel96());    
      ph->RegisterProcess(msc, particle);
      
      // activate ionisation
      G4eIonisation* eIoni = new G4eIonisation();
      eIoni->SetStepFunction(0.1, 100*um);      
      ph->RegisterProcess(eIoni, particle);
      
      // activate bremsstrahlung
      ph->RegisterProcess(new G4eBremsstrahlung(), particle);
      
      // activate annihilation
      ph->RegisterProcess(new G4eplusAnnihilation(), particle);
                  
    } 

    // define EM physics for muons 
    else if (particleName == "mu+" || particleName == "mu-") {

      // activate multiple scattering
      ph->RegisterProcess(new G4MuMultipleScattering(), particle);

      // activate ionisation
      G4MuIonisation* muIoni = new G4MuIonisation();
      muIoni->SetStepFunction(0.1, 50*um);      
      ph->RegisterProcess(muIoni, particle);

      // activate bremsstrahlung
      ph->RegisterProcess(new G4MuBremsstrahlung(), particle);

      // activate pair production
      ph->RegisterProcess(new G4MuPairProduction(), particle);
                   
    } 

    // define EM physics for protons and pions
    else if( particleName == "proton" ||
	     particleName == "pi-" ||
	     particleName == "pi+") {

      // activate multiple scattering
      ph->RegisterProcess(new G4hMultipleScattering(), particle);   

      // activate ionisation
      G4hIonisation* hIoni = new G4hIonisation();
      hIoni->SetStepFunction(0.1, 20*um);
      ph->RegisterProcess(hIoni, particle);

      // activate bremsstrahlung
      ph->RegisterProcess(new G4hBremsstrahlung(), particle);

      // activate pair production
      ph->RegisterProcess(new G4hPairProduction(), particle);            
     
    } 

    // define EM physics for alpha and helium-3
    else if( particleName == "alpha" || 
	     particleName == "He3") {

      // activate multiple scattering
      ph->RegisterProcess(new G4hMultipleScattering(), particle);   

      // activate ionisation
      G4ionIonisation* ionIoni = new G4ionIonisation();
      ionIoni->SetStepFunction(0.1, 1*um);
      ph->RegisterProcess(ionIoni, particle);

      // activate nuclear stopping
      ph->RegisterProcess(new G4NuclearStopping(), particle);      
            
    } 

    // define EM physics for all the other ions
    else if( particleName == "GenericIon" ) {

      // activate multiple scattering
      ph->RegisterProcess(new G4hMultipleScattering(), particle);   

      // activate ionisation
      G4ionIonisation* ionIoni = new G4ionIonisation();
      ionIoni->SetEmModel(new G4IonParametrisedLossModel());
      ionIoni->SetStepFunction(0.1, 1*um);
      ph->RegisterProcess(ionIoni, particle);

      // activate nuclear stopping
      ph->RegisterProcess(new G4NuclearStopping(), particle);                   
      
    } 

    // activate EM physics for all others charged particles except geantino
    else if ((!particle->IsShortLived()) &&
	     (particle->GetPDGCharge() != 0.0) && 
	     (particle->GetParticleName() != "chargedgeantino")) {
               
      // activate multiple scattering
      ph->RegisterProcess(new G4hMultipleScattering(), particle);

      // activate ionisation
      ph->RegisterProcess(new G4hIonisation(), particle);
    }
  }
}

void AnElectroMagneticPhysicsList::SetCuts()
{
  // set global cuts
  SetCutsWithDefault();
}




#else 
//*****************************************
//              for geant4.10             *
//*****************************************
#include "G4LossTableManager.hh"

#include "G4BosonConstructor.hh"
#include "G4LeptonConstructor.hh"
#include "G4MesonConstructor.hh"
#include "G4BosonConstructor.hh"
#include "G4BaryonConstructor.hh"
#include "G4IonConstructor.hh"
#include "G4ShortLivedConstructor.hh"

#include "G4ParticleDefinition.hh"
#include "G4ProcessManager.hh"
#include "G4PhysicsListHelper.hh"

#include "G4ComptonScattering.hh"
#include "G4GammaConversion.hh"
#include "G4PhotoElectricEffect.hh"
#include "G4RayleighScattering.hh"
#include "G4KleinNishinaModel.hh"

#include "G4eMultipleScattering.hh"
#include "G4UrbanMscModel.hh"
#include "G4eIonisation.hh"
#include "G4eBremsstrahlung.hh"
#include "G4eplusAnnihilation.hh"

#include "G4MuMultipleScattering.hh"
#include "G4MuIonisation.hh"
#include "G4MuBremsstrahlung.hh"
#include "G4MuPairProduction.hh"

#include "G4hMultipleScattering.hh"
#include "G4hIonisation.hh"
#include "G4hBremsstrahlung.hh"
#include "G4hPairProduction.hh"

#include "G4ionIonisation.hh"
#include "G4IonParametrisedLossModel.hh"
#include "G4NuclearStopping.hh"
#include "G4SystemOfUnits.hh"


AnElectroMagneticPhysicsList::AnElectroMagneticPhysicsList()
{
  G4LossTableManager::Instance();
  defaultCutValue = 1.0*CLHEP::mm;

  G4cout << G4endl << " ------ INFO ------ You are working with an electromagnetic PhysicsList (transportation and electromagnetic processes)" << G4endl;
}


AnElectroMagneticPhysicsList::~AnElectroMagneticPhysicsList()
{}



void AnElectroMagneticPhysicsList::ConstructParticle()
{
  // define all particles
  G4cout << G4endl << " ------ INFO ------ DEFINING PARTICLES:" << G4endl;
  G4BosonConstructor  pBosonConstructor;
  pBosonConstructor.ConstructParticle();
  G4cout << "DEFINED: Bosons" << G4endl;

  G4LeptonConstructor pLeptonConstructor;
  pLeptonConstructor.ConstructParticle();
  G4cout << "DEFINED: Leptons" << G4endl;

  G4MesonConstructor pMesonConstructor;
  pMesonConstructor.ConstructParticle();
  G4cout << "DEFINED: Mesons" << G4endl;
  
  G4BaryonConstructor pBaryonConstructor;
  pBaryonConstructor.ConstructParticle();
  G4cout << "DEFINED: Baryons" << G4endl;
  
  G4IonConstructor pIonConstructor;
  pIonConstructor.ConstructParticle();
  G4cout << "DEFINED: Ions" << G4endl;

  G4ShortLivedConstructor pShortLivedConstructor;
  pShortLivedConstructor.ConstructParticle();  
  G4cout << "DEFINED: Short lived particles" << G4endl;

  G4cout << " ------ INFO ------ PARTICLES DEFINITION FINISHED" << G4endl;
}



void AnElectroMagneticPhysicsList::ConstructProcess()
{
  /* ###############################################
     ############### TRANSPORTATION ################
     ############################################### */

  AddTransportation();


  /* ###############################################
     ########## ELECTROMAGNETIC PROCESSES ##########
     ############################################### */

  G4PhysicsListHelper* ph = G4PhysicsListHelper::GetPhysicsListHelper();

  theParticleIterator->reset();
  while( (*theParticleIterator)() ){
    G4ParticleDefinition* particle = theParticleIterator->value();
    G4String particleName = particle->GetParticleName();
     

    // define EM physics for gamma
    if (particleName == "gamma") {
      
      // activate photoelectric effect
      ph->RegisterProcess(new G4PhotoElectricEffect, particle);  
      
      // activate Compton scattering
      G4ComptonScattering* cs   = new G4ComptonScattering;
      cs->SetEmModel(new G4KleinNishinaModel());
      ph->RegisterProcess(cs, particle);

      // activate gamma conversion
      ph->RegisterProcess(new G4GammaConversion, particle);
     
    } 
    
    // define EM physics for electron
    else if (particleName == "e-") {

      // activate multiple scattering
      G4eMultipleScattering* msc = new G4eMultipleScattering();
      msc -> AddEmModel(0, new G4UrbanMscModel());    
      ph->RegisterProcess(msc, particle);
      
      // activate ionisation             
      G4eIonisation* eIoni = new G4eIonisation();
      eIoni->SetStepFunction(0.1, 100*CLHEP::um);      
      ph->RegisterProcess(eIoni, particle);
      
      // activate bremsstrahlung
      ph->RegisterProcess(new G4eBremsstrahlung(), particle);      
            
    } 

    // define EM physics for positron
    else if (particleName == "e+") {
    
      // activate multiple scattering
      G4eMultipleScattering* msc = new G4eMultipleScattering();
      msc -> AddEmModel(0, new G4UrbanMscModel());    
      ph->RegisterProcess(msc, particle);
      
      // activate ionisation
      G4eIonisation* eIoni = new G4eIonisation();
      eIoni->SetStepFunction(0.1, 100*CLHEP::um);      
      ph->RegisterProcess(eIoni, particle);
      
      // activate bremsstrahlung
      ph->RegisterProcess(new G4eBremsstrahlung(), particle);
      
      // activate annihilation
      ph->RegisterProcess(new G4eplusAnnihilation(), particle);
                  
    } 

    // define EM physics for muons 
    else if (particleName == "mu+" || particleName == "mu-") {

      // activate multiple scattering
      ph->RegisterProcess(new G4MuMultipleScattering(), particle);

      // activate ionisation
      G4MuIonisation* muIoni = new G4MuIonisation();
      muIoni->SetStepFunction(0.1, 50*CLHEP::um);      
      ph->RegisterProcess(muIoni, particle);

      // activate bremsstrahlung
      ph->RegisterProcess(new G4MuBremsstrahlung(), particle);

      // activate pair production
      ph->RegisterProcess(new G4MuPairProduction(), particle);
                   
    } 

    // define EM physics for protons and pions
    else if( particleName == "proton" ||
	     particleName == "pi-" ||
	     particleName == "pi+") {

      // activate multiple scattering
      ph->RegisterProcess(new G4hMultipleScattering(), particle);   

      // activate ionisation
      G4hIonisation* hIoni = new G4hIonisation();
      hIoni->SetStepFunction(0.1, 20*CLHEP::um);
      ph->RegisterProcess(hIoni, particle);

      // activate bremsstrahlung
      ph->RegisterProcess(new G4hBremsstrahlung(), particle);

      // activate pair production
      ph->RegisterProcess(new G4hPairProduction(), particle);            
     
    } 

    // define EM physics for alpha and helium-3
    else if( particleName == "alpha" || 
	     particleName == "He3") {

      // activate multiple scattering
      ph->RegisterProcess(new G4hMultipleScattering(), particle);   

      // activate ionisation
      G4ionIonisation* ionIoni = new G4ionIonisation();
      ionIoni->SetStepFunction(0.1, 1*CLHEP::um);
      ph->RegisterProcess(ionIoni, particle);

      // activate nuclear stopping
      ph->RegisterProcess(new G4NuclearStopping(), particle);      
            
    } 

    // define EM physics for all the other ions
    else if( particleName == "GenericIon" ) {

      // activate multiple scattering
      ph->RegisterProcess(new G4hMultipleScattering(), particle);   

      // activate ionisation
      G4ionIonisation* ionIoni = new G4ionIonisation();
      ionIoni->SetEmModel(new G4IonParametrisedLossModel());
      ionIoni->SetStepFunction(0.1, 1*CLHEP::um);
      ph->RegisterProcess(ionIoni, particle);

      // activate nuclear stopping
      ph->RegisterProcess(new G4NuclearStopping(), particle);                   
      
    } 

    // activate EM physics for all others charged particles except geantino
    else if ((!particle->IsShortLived()) &&
	     (particle->GetPDGCharge() != 0.0) && 
	     (particle->GetParticleName() != "chargedgeantino")) {
               
      // activate multiple scattering
      ph->RegisterProcess(new G4hMultipleScattering(), particle);

      // activate ionisation
      ph->RegisterProcess(new G4hIonisation(), particle);
    }
  }
}

void AnElectroMagneticPhysicsList::SetCuts()
{
  // set global cuts
  SetCutsWithDefault();
}
#endif
